@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.22
+# Version   : 0.2.23
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -842,7 +842,7 @@ class AFM:
         self.adhesion = np.zeros(self.z_approach.shape[1])
 
         for curve_number in range(0, self.z_approach.shape[1]):
-            self.adhesion[curve_number] = np.amin(self.retract[:, curve_number]) * -1
+            self.adhesion[curve_number] = np.nanmin(self.retract[:, curve_number]) * -1
 
         if plot_hist is True:
             fig = go.Figure(data = [go.Histogram(x = self.adhesion)])
